# {{package_name}}

This project has been generated by the Pole Emploi IA templates.
For more documentations on these templates, please refer to the GitHub project.

## 0. Installation

- (optionnal) We strongly encourage you to use a python virtual environment

	- `pip install virtualenv`

	- `python -m venv my_awesome_venv`

	- `cd my_awesome_venv/Scripts/ && activate` (windows) or `source my_awesome_venv/bin/activate` (linux)

- Requirements installation : `pip install -r requirements.txt{% if pip_trusted_host is not none %} --trusted-host {{pip_trusted_host}}{% endif %}{% if pip_index_url is not none %} --index-url {{pip_index_url}}{% endif %}`

- Project setup (in develop mode !) : `python setup.py develop`


If `make` is installed on your computer, you can simply use the `Makefile` features:

- `create-virtualenv`: creates a new virtual environment

- `init-local-env`: init. your environment with the project


## 1. TODO

** TO BE COMPLETED **
